pub struct ModelChecker { /* private fields */ }Expand description
Main class of (and entrypoint to) the model checking testing technique.
Implementations
Sourceimpl ModelChecker
impl ModelChecker
Sourcepub fn new(sys: &System) -> Self
pub fn new(sys: &System) -> Self
Creates a new model checker with the specified strategy and initial state equal to the current state of the system.
Sourcepub fn run<S: Strategy>(&mut self, strategy_config: StrategyConfig) -> McResult
pub fn run<S: Strategy>(&mut self, strategy_config: StrategyConfig) -> McResult
Runs model checking and returns the result on completion.
Sourcepub fn run_with_change<S>(
&mut self,
strategy_config: StrategyConfig,
preliminary_callback: impl FnOnce(&mut McSystem),
) -> McResultwhere
S: Strategy,
pub fn run_with_change<S>(
&mut self,
strategy_config: StrategyConfig,
preliminary_callback: impl FnOnce(&mut McSystem),
) -> McResultwhere
S: Strategy,
Runs model checking after applying callback.
Sourcepub fn run_from_states<S: Strategy>(
&mut self,
strategy_config: StrategyConfig,
states: HashSet<McState>,
) -> McResult
pub fn run_from_states<S: Strategy>( &mut self, strategy_config: StrategyConfig, states: HashSet<McState>, ) -> McResult
Runs model checking from a set of initial states.
Sourcepub fn run_from_states_with_change<S>(
&mut self,
strategy_config: StrategyConfig,
states: HashSet<McState>,
preliminary_callback: impl Fn(&mut McSystem),
) -> McResultwhere
S: Strategy,
pub fn run_from_states_with_change<S>(
&mut self,
strategy_config: StrategyConfig,
states: HashSet<McState>,
preliminary_callback: impl Fn(&mut McSystem),
) -> McResultwhere
S: Strategy,
Runs model checking from a set of initial states after applying callback.